﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Diagnostics;
using ServiceStack.OrmLite;

namespace TestOrmLite
{
    internal static class Program
    {
        private static void Main()
        {
            var watch = new Stopwatch();
            IDbConnection db = null;


            try
            {
                #region ORM配置及启动

                watch.Start();
                OrmLiteConfig.DialectProvider = SqlServerDialect.Provider;
                string connStr = ConfigurationManager.ConnectionStrings["SSConnection"].ConnectionString;
                db = connStr.OpenDbConnection();
                watch.Stop();
                Console.WriteLine("ORM配置及启动：" + watch.ElapsedMilliseconds);

                #endregion

                #region 先删表

                db.DropTable<Person>();
                db.DropTable<School>();

                #endregion

                #region 建表

                watch.Restart();
                db.CreateTable<School>();
                db.CreateTable<Person>();
                watch.Stop();
                Console.WriteLine("建表：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目1

                watch.Restart();
                var schools = new List<School>();

                for (int i = 1; i < 101; i++)
                {
                    schools.Add(new School
                    {
                        ID = Guid.NewGuid(),
                        Name = "SSS",
                        AllPersonCount = i
                    });
                }

                db.InsertAll(schools);
                watch.Stop();
                Console.WriteLine("测试项目1：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目2

                schools = db.LoadSelect<School>();
                watch.Restart();
                var students = new List<Person>();

                schools.ForEach(o =>
                {
                    for (int i = 1; i < 1001; i++)
                    {
                        students.Add(new Person
                        {
                            Age = i,
                            Name = "PPP",
                            ShoolID = o.ID
                        });
                    }
                });

                db.InsertAll(students);
                watch.Stop();
                Console.WriteLine("测试项目2：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目3

                watch.Restart();
                List<Person> persons = db.Select<Person>(x => x.Age > 30);
                watch.Stop();
                Console.WriteLine("测试项目3：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目4

                watch.Restart();
                persons.ForEach(o => o.Age += 20);
                db.UpdateAll(persons);
                watch.Stop();
                Console.WriteLine("测试项目4：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目5

                watch.Restart();
                students = db.Select(
                    db.From<Person>()
                        .Join<School>((p, s) => p.ShoolID == s.ID)
                        .Where<School>(s => s.AllPersonCount > 5)
                    );
                watch.Stop();
                Console.WriteLine("测试项目5：" + watch.ElapsedMilliseconds);

                #endregion

                #region 测试项目6

                watch.Restart();
                long count = db.Count(
                    db.From<Person>()
                        .Join<School>((p, s) => p.ShoolID == s.ID)
                        .Where<School>(s => s.AllPersonCount > 6)
                    );
                watch.Stop();
                Console.WriteLine("测试项目6：" + watch.ElapsedMilliseconds);

                #endregion
            }
            catch (Exception e)
            {
                Console.WriteLine(e);
            }
            finally
            {
                if (db != null) db.Dispose();
            }

            Console.ReadKey();
        }
    }
}